@@ -2,10 +2,12 @@
 from . import common
 from . import matrix
 from . import occurrence
+from . import species_list
 from . import tree
 
 __all__ = []
 __all__.extend(common.__all__)
 __all__.extend(matrix.__all__)
 __all__.extend(occurrence.__all__)
+__all__ .extend(species_list.__all__)
 __all__.extend(tree.__all__)
