@@ -1,7 +1,10 @@
 """Spatial tools."""
 # flake8: noqa
+from . import geojsonify
 from . import spatial_index
+from .geojsonify import *
 from .spatial_index import *
 
 __all__ = []
+__all__.extend(geojsonify.__all__)
 __all__.extend(spatial_index.__all__)
