@@ -13,9 +13,16 @@ DESCRIPTION = 'Convert a lmpy Matrix to a GeoJSON file.'
 
 
 # .....................................................................................
-def cli():
-    """Provide a command-line tool for converting LMM to GeoJSON."""
-    parser = argparse.ArgumentParser(description=DESCRIPTION)
+def build_parser():
+    """Build an argparse.ArgumentParser object for the tool.
+
+    Returns:
+        argparse.ArgumentParser: An argument parser for the tool's parameters.
+    """
+    parser = argparse.ArgumentParser(
+        prog='convert_lmm_to_geojson',
+        description=DESCRIPTION,
+    )
     parser.add_argument('--config_file', type=str, help='Path to configuration file.')
     parser.add_argument(
         '--shapefile_filename',
@@ -51,6 +58,13 @@ def cli():
         type=str,
         help='Location to write the converted matrix GeoJSON.',
     )
+    return parser
+
+
+# .....................................................................................
+def cli():
+    """Provide a command-line tool for converting LMM to GeoJSON."""
+    parser = build_parser()
     args = _process_arguments(parser, config_arg='config_file')
     mtx = Matrix.load(args.in_lmm_filename)
     if args.shapefile_filename is not None:
@@ -66,7 +80,7 @@ def cli():
 
 
 # .....................................................................................
-__all__ = ['cli']
+__all__ = ['build_parser', 'cli']
 
 
 # .....................................................................................
